@@ -55,6 +55,7 @@ import ldb
 import samba.getopt
 from samba.auth import system_session
 from univention import config_registry
+from samba import credentials
 
 
 parser = optparse.OptionParser("$prog [options] <host>")
@@ -74,6 +75,7 @@ parser.add_option("--modifysubnet", action="store_true", dest="modifysubnet")
 parser.add_option("--site", dest="site")
 parser.add_option("--sitelink", dest="sitelink")
 parser.add_option("--subnet", dest="subnet")
+parser.add_option("-A", "--authentication-file", dest="authentication_file", help="Get the credentials from a file")
 opts, args = parser.parse_args()
 
 if not opts.database_url:
@@ -102,7 +104,11 @@ if not (opts.createsitelink or opts.createsite or opts.createsubnet or opts.modi
 	parser.print_help()
 
 lp = sambaopts.get_loadparm()
-creds = credopts.get_credentials(lp)
+if opts.authentication_file:
+	creds = credentials.Credentials()
+	creds.parse_file(opts.authentication_file)
+else:
+	creds = credopts.get_credentials(lp)
 
 configRegistry = config_registry.ConfigRegistry()
 configRegistry.load()
